@@ -1,3 +1,7 @@
+"""Utils function for .rawls file
+"""
+
+
 # utils functions
 def check_file_paths(filepaths):
     """check filepaths input extension
@@ -14,4 +18,4 @@ def check_file_paths(filepaths):
         raise Exception('Need at least two rawls image filepaths as input')
 
     if not all(['.rawls' in p for p in filepaths]):
-        raise Exception('Unvalid input filepath images, need .rawls image')
\ No newline at end of file
+        raise Exception('Unvalid input filepath images, need .rawls image')
